package com.yidianling.consultant.modular.singlton

import android.app.Activity
import android.support.v7.app.AppCompatActivity
import com.yidianling.common.tools.ToastUtil
import com.yidianling.consultant.dialog.ConsultAssistantDialog
import com.yidianling.consultant.model.SearchApi
import com.yidianling.consultant.router.ConsultantIn
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import java.util.*

/**
 * Created by xj on 2019/11/14.
 */
class ConsultAssistantDialogUtils private constructor(){

    companion object {
        val INSTANCE by lazy { ConsultAssistantDialogUtils() }
    }

    var consultAssistantDialog: ConsultAssistantDialog? = null
    var expertSearchPageHasShown: Boolean = false // 专家咨询列表页面是否已经展示
    var timer: Timer? = null


    /**
     *判断是否符合代码展示逻辑
     * origin 展示请求来源    首页 home_index 咨询列表 doctor_list
     */
    fun fitRequest(activity: Activity, origin: String) {
        if (ConsultantIn.isLogin() &&
                ConsultantIn.getUserImpl().getUserInfo()?.user_type == 1
        /** WalleChannelReader.getChannel(BaseApp.Companion.getApp()) == "android_huawei" */
                ) {
            shouldShowDialog(activity, origin)
        }
    }

    /**
     * 判断是否符合接口展示逻辑
     */
    private fun shouldShowDialog(activity: Activity, origin: String, isDelay: Boolean = false) {
        // 请求接口判断导医咨询助理按钮是否展示
        SearchApi.getSearchApi().getConsultAssistantRequest(origin)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe{
                    if (it.data) {
                        if (origin == "home_index") {
                            show(activity, false)
                        }else if (origin == "doctor_list") {
                            show(activity, true)
                        }
                    }
                }
    }

    /**
     * 展示
     * isDelay 是否延迟展示
     */
    fun show(activity: Activity, isDelay: Boolean) {

        if (isDelay && !expertSearchPageHasShown && timer == null) {
            timer = Timer()
            timer!!.schedule(object : TimerTask() {
                override fun run() {
                    showDialog(activity)
                    expertSearchPageHasShown = true
                }
            }, 10000)
        }else {
            showDialog(activity)
        }
    }

    /**
     * 展示浮层
     */
    fun showDialog(activity: Activity) {
        if (consultAssistantDialog == null) {
            consultAssistantDialog = ConsultAssistantDialog(activity, object : ConsultAssistantDialog.OnConsultAssistantClickListener {
                override fun onClickAction() {
                    //获取用户uid
                    getConsultAssistantUid(activity)
                }

            })
        }
        consultAssistantDialog!!.show()
    }


    /**
     * 隐藏
     */
    fun hide() {
        consultAssistantDialog?.hide()
    }

    /**
     * 重置本单例关于专家咨询列表页面得状态
     */
    fun resetStatus() {
        timer?.cancel()
        timer = null
        expertSearchPageHasShown = false
    }

    private fun getConsultAssistantUid(activity: Activity) {
        // 请求接口获取咨询助理的uid
        SearchApi.getSearchApi().getConsultAssistantUidRequest()
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe{
                    if (it.code == "200" && it.data != 0.toLong()) {
                        ConsultantIn.startP2PSession(activity as AppCompatActivity, it.data.toString())
                    }else {
                        ToastUtil.toastShort("咨询助理忙碌中，请稍后再试")
                    }
                }
    }
}